CKEDITOR.plugins.setLang('youtube', 'nn', {
	button : 'Bygg inn YouTube-video',
	title : 'Bygg inn YouTube-video',
	txtEmbed : 'Lim inn embed-kode her',
	txtUrl : 'Lim inn YouTube video-URL',
	txtWidth : 'Breidde',
	txtHeight : 'Høgde',
	chkRelated : 'Vis foreslåtte videoar når videoen er ferdig',
	txtStartAt : 'Start ved (ss eller mm:ss eller hh:mm:ss)',
	chkPrivacy : 'Bruk personverntilpassa modus',
	chkOlderCode : 'Bruk gamal embedkode',
	chkAutoplay: 'Spel automatisk',
	chkControls: 'Vis spillerkontrollene',
	noCode : 'Du må leggja inn ein embed-kode eller URL',
	invalidEmbed : 'Emded-koden du la inn ser ikkje ut til å vera gyldig',
	invalidUrl : 'URLen du la inn ser ikkje ut til å vera gyldig',
	or : 'eller',
	noWidth : 'Du må leggja inn breidde',
	invalidWidth : 'Legg inn ei gyldig breidde',
	noHeight : 'Du må leggja inn høgde',
	invalidHeight : 'Legg inn ei gyldig høgde',
	invalidTime : 'Legg inn gyldig starttid',
	txtResponsive : 'Gjer responsiv (ignorer breidde og høgde, tilpass breidda på sida)'
});
